Struct ZxdgImporterV1
pub struct ZxdgImporterV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
interface for importing surfaces
A global interface used for importing surfaces exported by xdg_exporter. With this interface, a client can create a reference to a surface of another client.
This interface has no events.
Implementations
impl ZxdgImporterV1
impl ZxdgImporterV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the xdg_importer object
Notify the compositor that the xdg_importer object will no longer be used.
pub fn import<U, D>(
&self,
handle: String,
qh: &QueueHandle<D>,
udata: U,
) -> ZxdgImportedV1
pub fn import<U, D>( &self, handle: String, qh: &QueueHandle<D>, udata: U, ) -> ZxdgImportedV1
import a surface
The import request imports a surface from any client given a handle retrieved by exporting said surface using xdg_exporter.export. When called, a new xdg_imported object will be created. This new object represents the imported surface, and the importing client can manipulate its relationship using it. See xdg_imported for details.